@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Colin Leroy <colin@colino.net> 
+ * Copyright (C) 1999-2011 Colin Leroy <colin@colino.net> 
  * and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -493,8 +493,8 @@ static gboolean ssl_certificate_compare (SSLCertificate *cert_a, SSLCertificate
 		return FALSE;
 	}
 
-	output_a = malloc(cert_size_a);
-	output_b = malloc(cert_size_b);
+	output_a = g_malloc(cert_size_a);
+	output_b = g_malloc(cert_size_b);
 	if ((r = gnutls_x509_crt_export(cert_a->x509_cert, GNUTLS_X509_FMT_DER, output_a, &cert_size_a)) < 0) {
 		g_warning("couldn't gnutls_x509_crt_export a %s\n", gnutls_strerror(r));
 		g_free(output_a);
