@@ -593,8 +593,9 @@ static void login_run(struct etpan_thread_op * op)
 #endif
 
 	r = newsnntp_authinfo_username(param->nntp, param->login);
-	if (r == NEWSNNTP_NO_ERROR || 
-	    r == NEWSNNTP_WARNING_REQUEST_AUTHORIZATION_PASSWORD) {
+	/* libetpan returning NO_ERROR means it received resp.code 281:
+	   in this case auth. is already successful, no password is needed. */
+	if (r == NEWSNNTP_WARNING_REQUEST_AUTHORIZATION_PASSWORD) {
 		r = newsnntp_authinfo_password(param->nntp, param->password);
 	}
 	
