@@ -33,7 +33,9 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <sys/types.h>
-#include <sys/wait.h>
+#if HAVE_SYS_WAIT_H
+#  include <sys/wait.h>
+#endif
 #include <signal.h>
 #include <ctype.h>
 #include <string.h>
@@ -388,6 +390,8 @@ GtkAspell *gtkaspell_new(const gchar *dictionary,
 		if (!alt_gtkaspeller) {
 			gtkaspell_checkers_error_message(
 				g_strdup_printf(_("Couldn't initialize %s speller."), dictionary));
+			gtkaspeller_delete(gtkaspeller);
+			g_free(gtkaspell);
 			return NULL;
 		}
 
@@ -664,6 +668,7 @@ static GtkAspeller *gtkaspeller_real_new(Dictionary *dict)
 	if (!broker) {
 		gtkaspell_checkers_error_message(
 				g_strdup(_("Couldn't initialize Enchant broker.")));
+		g_free(gtkaspeller);
 		return NULL;
 	}
 	if ((speller = set_dictionary(broker, dict)) == NULL) {
@@ -671,6 +676,7 @@ static GtkAspeller *gtkaspeller_real_new(Dictionary *dict)
 				g_strdup_printf(_("Couldn't initialize %s dictionary:"), dict->fullname));
 		gtkaspell_checkers_error_message(
 				g_strdup(enchant_broker_get_error(broker)));
+		g_free(gtkaspeller);
 		return NULL;
 	}
 	gtkaspeller->speller = speller;
