@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2002-2007 by the Claws Mail Team and Hiroyuki Yamamoto
+ * Copyright (C) 2002-2011 by the Claws Mail Team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ void folder_remote_folder_init(Folder *folder, const gchar *name,
 
 void folder_remote_folder_destroy(RemoteFolder *rfolder)
 {
-	g_return_if_fail(rfolder != NULL);
+	cm_return_if_fail(rfolder != NULL);
 
 	if (rfolder->session)
 		session_destroy(rfolder->session);
